==> dr-server-0.0.26.tgz: package/module/HTML/Modal.js <==
const initModal = () => {
  const {cE, aCL, Dr: {Common: {Error: {catchAsync}}}} = window;
  const FULLSCREEN_STYLE = "position: absolute; top: 0; left: 0; width: 100vw; height: 100vh;";
  const renderModal = () => {
    const modalMaskDiv = cE("div", {
      style: `${FULLSCREEN_STYLE} background: rgba(0, 0, 0, 0.4);`
    });
    const modalMainDiv = cE("div", {
      style: "position: relative; overflow-y: auto; margin: 8px; padding: 4px; width: 640px; max-width: 92vw; min-width: 240px; background: #fff; box-shadow: 0 0 2px 0 #666;"
    });
    return {
      modalDiv: cE("div", {
        style: `${FULLSCREEN_STYLE} display: flex; flex-flow: column; align-items: center; justify-content: center; z-index: 16777215;`
      }, [ modalMaskDiv, modalMainDiv ]),
      modalMaskDiv,
      modalMainDiv
    };
  };
  const withModal = async func => {
    const {modalDiv, modalMaskDiv, modalMainDiv} = renderModal();
    document.body.appendChild(modalDiv);
    const {result, error} = await catchAsync(func, {
      modalDiv,
      modalMaskDiv,
      modalMainDiv
    });
    modalDiv.remove();
    if (error) throw error;
    return result;
  };
  const COMMON_FLEX_STYLE = {
    display: "flex",
    flexFlow: "column"
  };
  const createFlexRow = (...args) => cE("div", {
    style: "display: flex; flex-flow: row; align-items: center; justify-content: center;"
  }, args);
  const createMessage = message => cE("pre", {
    innerText: message,
    style: "overflow: auto; max-height: 64vh; min-height: 2em; white-space: pre-wrap;"
  });
  return {
    MODAL_Z_INDEX: 16777215,
    renderModal,
    withModal,
    withAlertModal: async message => withModal(({modalMainDiv}) => new Promise(resolve => {
      Object.assign(modalMainDiv.style, COMMON_FLEX_STYLE);
      const confirmButton = cE("button", {
        innerText: "Confirm",
        onclick: resolve
      });
      aCL(modalMainDiv, [ createMessage(message), createFlexRow(confirmButton) ]);
      setTimeout(() => confirmButton.focus(), 200);
    })),
    withConfirmModal: async message => withModal(({modalMainDiv}) => new Promise(resolve => {
      Object.assign(modalMainDiv.style, COMMON_FLEX_STYLE);
      const confirmButton = cE("button", {
        innerText: "Confirm",
        onclick: () => resolve(!0)
      });
      aCL(modalMainDiv, [ createMessage(message), createFlexRow(cE("button", {
        innerText: "Cancel",
        onclick: () => resolve(!1)
      }), confirmButton) ]);
      setTimeout(() => confirmButton.focus(), 200);
    })),
    withPromptModal: async (message, defaultValue = "") => withModal(({modalMainDiv}) => new Promise(resolve => {
      Object.assign(modalMainDiv.style, COMMON_FLEX_STYLE);
      const promptInput = cE("input", {
        value: defaultValue
      });
      aCL(modalMainDiv, [ createMessage(message), promptInput, createFlexRow(cE("button", {
        innerText: "Cancel",
        onclick: () => resolve(null)
      }), cE("button", {
        innerText: "Confirm",
        onclick: () => resolve(promptInput.value)
      })) ]);
      setTimeout(() => promptInput.focus(), 200);
    }))
  };
};
export { initModal };

==> dr-server-0.2.0-dev.1.tgz: package/module/HTML/Modal.js <==
const initModal = () => {
  const {cE, aCL, Dr: {Common: {Error: {catchAsync}}}} = window;
  const FULLSCREEN_STYLE = "position: absolute; top: 0; left: 0; width: 100vw; height: 100vh;";
  const renderModal = () => {
    const modalMaskDiv = cE("div", {
      style: `${FULLSCREEN_STYLE} background: rgba(0, 0, 0, 0.4);`
    });
    const modalMainDiv = cE("div", {
      style: "position: relative; overflow-y: auto; margin: 8px; padding: 4px; width: 640px; max-width: 92vw; min-width: 240px; background: #fff; box-shadow: 0 0 2px 0 #666;"
    });
    return {
      modalDiv: cE("div", {
        style: `${FULLSCREEN_STYLE} display: flex; flex-flow: column; align-items: center; justify-content: center; z-index: 16777215;`
      }, [ modalMaskDiv, modalMainDiv ]),
      modalMaskDiv,
      modalMainDiv
    };
  };
  const withModal = async func => {
    const {modalDiv, modalMaskDiv, modalMainDiv} = renderModal();
    document.body.appendChild(modalDiv);
    const {result, error} = await catchAsync(func, {
      modalDiv,
      modalMaskDiv,
      modalMainDiv
    });
    modalDiv.remove();
    if (error) throw error;
    return result;
  };
  const COMMON_FLEX_STYLE = {
    display: "flex",
    flexFlow: "column"
  };
  const createFlexRow = (...args) => cE("div", {
    style: "display: flex; flex-flow: row; align-items: center; justify-content: center;"
  }, args);
  const createMessage = message => cE("pre", {
    innerText: message,
    style: "overflow: auto; max-height: 64vh; white-space: pre;"
  });
  return {
    MODAL_Z_INDEX: 16777215,
    renderModal,
    withModal,
    withAlertModal: async message => withModal(({modalMainDiv}) => new Promise(resolve => {
      Object.assign(modalMainDiv.style, COMMON_FLEX_STYLE);
      const confirmButton = cE("button", {
        innerText: "Confirm",
        onclick: resolve
      });
      aCL(modalMainDiv, [ createMessage(message), createFlexRow(confirmButton) ]);
      setTimeout(() => confirmButton.focus(), 200);
    })),
    withConfirmModal: async (message, textConfirm = "Confirm", textCancel = "Cancel") => withModal(({modalMainDiv}) => new Promise(resolve => {
      Object.assign(modalMainDiv.style, COMMON_FLEX_STYLE);
      const confirmButton = cE("button", {
        innerText: textConfirm,
        onclick: () => resolve(!0)
      });
      aCL(modalMainDiv, [ createMessage(message), createFlexRow(cE("button", {
        innerText: textCancel,
        onclick: () => resolve(!1)
      }), confirmButton) ]);
      setTimeout(() => confirmButton.focus(), 200);
    })),
    withPromptModal: async (message, defaultValue = "", textConfirm = "Confirm", textCancel = "Cancel") => withModal(({modalMainDiv}) => new Promise(resolve => {
      Object.assign(modalMainDiv.style, COMMON_FLEX_STYLE);
      const promptInput = cE("input", {
        value: defaultValue
      });
      aCL(modalMainDiv, [ createMessage(message), promptInput, createFlexRow(cE("button", {
        innerText: textCancel,
        onclick: () => resolve(null)
      }), cE("button", {
        innerText: textConfirm,
        onclick: () => resolve(promptInput.value)
      })) ]);
      setTimeout(() => promptInput.focus(), 200);
    })),
    withPromptExtModal: async (inputInfoList, textConfirm = "Confirm", textCancel = "Cancel") => withModal(({modalMainDiv}) => new Promise(resolve => {
      Object.assign(modalMainDiv.style, COMMON_FLEX_STYLE);
      const inputElementList = inputInfoList.reduce((o, [message, defaultValue = ""]) => {
        o.push(createMessage(message), cE("input", {
          value: defaultValue
        }));
        return o;
      }, []);
      console.log({
        inputInfoList,
        inputElementList
      });
      aCL(modalMainDiv, [ ...inputElementList, createFlexRow(cE("button", {
        innerText: textCancel,
        onclick: () => resolve(null)
      }), cE("button", {
        innerText: textConfirm,
        onclick: () => resolve(inputElementList.filter((v, index) => index % 2).map(inputElement => inputElement.value))
      })) ]);
      setTimeout(() => inputElementList[1].focus(), 200);
    }))
  };
};
export { initModal };
